.. _spkg_sagemath_gap_pkg_normalizinterface:

=====================================================================================================
sagemath_gap_pkg_normalizinterface: Computational Group Theory with GAP: normalizinterface package
=====================================================================================================


This pip-installable distribution ``passagemath-gap-pkg-normalizinterface`` is a
distribution of the GAP package ``normalizinterface`` for use with ``passagemath-gap``.


What is included
----------------

- Wheels on PyPI include the GAP package ``normalizinterface``


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cython`
- :ref:`spkg_gap_pkg_normalizinterface`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_setuptools`

Version Information
-------------------

package-version.txt::

    10.8.2.rc0

version_requirements.txt::

    passagemath-gap-pkg-normalizinterface == 10.8.2rc0

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install passagemath-gap-pkg-normalizinterface==10.8.2rc0

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sagemath_gap_pkg_normalizinterface


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
